@@ -2,8 +2,8 @@
 ## src/common/defs.py
 ##
 ## Copyright (C) 2006 Nikos Kouremenos <kourem AT gmail.com>
-## Copyright (C) 2006-2008 Yann Leboulanger <asterix AT lagaule.org>
-##                         Jean-Marie Traissard <jim AT lapin.org>
+## Copyright (C) 2006-2012 Yann Leboulanger <asterix AT lagaule.org>
+## Copyright (C) 2006-2008 Jean-Marie Traissard <jim AT lapin.org>
 ## Copyright (C) 2007 Brendan Taylor <whateley AT gmail.com>
 ##                    Tomasz Melcer <liori AT exroot.org>
 ## Copyright (C) 2008 Jonathan Schleifer <js-gajim AT webkeks.org>
@@ -24,13 +24,19 @@
 ##
 
 docdir = '../'
-datadir = '../'
+basedir   = '../'
 localedir = '../po'
 
-version = '0.13.1'
+version = '0.15.2'
+import subprocess
+try:
+    node = subprocess.Popen('hg tip --template "{node|short}"', shell=True,
+        stdout=subprocess.PIPE).communicate()[0]
+    if node:
+        version += '-' + node
+except Exception:
+    pass
 
 import sys, os.path
 for base in ('.', 'common'):
-	sys.path.append(os.path.join(base, '.libs'))
-
-# vim: se ts=3:
+    sys.path.append(os.path.join(base, '.libs'))
